// -*- C++ -*-
// --------------------------------------------------------------------
// Support for loading/saving/running Latex
// --------------------------------------------------------------------
/*

    This file is part of the extensible drawing editor Ipe.
    Copyright (C) 1993-2007  Otfried Cheong

    Ipe is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    As a special exception, you have permission to link Ipe with the
    CGAL library and distribute executables, as long as you follow the
    requirements of the Gnu General Public License in regard to all of
    the software in the executable aside from CGAL.

    Ipe is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License
    along with Ipe; if not, you can find it at
    "http://www.gnu.org/copyleft/gpl.html", or write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef IPEMODEL_H
#define IPEMODEL_H

#include "ipedoc.h"

#include <qstring.h>

class QStringList;
class QDir;

// --------------------------------------------------------------------

class IpeModel {
public:
  static IpeDocument *New(const QString &fname, int &reason);

  static bool Save(const IpeDocument *doc, const QString &fname,
		   IpeString creator, IpeDocument::TFormat format,
		   uint flags = IpeDocument::ESaveNormal);

  static bool AddStyleSheet(IpeDocument *doc, const QString &fname);
  static IpeString UpdateStyleSheets(IpeDocument *doc, const QDir &dir);

  //! Error codes returned by RunLatex.
  enum { ErrNone, ErrNoText, ErrNoDir, ErrWritingSource,
	 ErrOldPdfLatex, ErrLatex, ErrAlreadyHaveForm,
	 ErrLatexOutput };
  static int RunLatex(IpeDocument *doc, bool needLatex,
		      const QStringList &styleDirs, QString &logFile);
  static int RunLatex(IpeDocument *doc);
};

// --------------------------------------------------------------------
#endif
